@@ -10,8 +10,7 @@ from netlink.logging import logger
 
 class Worker(threading.Thread):
     def __init__(self, name_index, api_key, site, queue, shutdown_event, *args, **kwargs):
-        # noinspection PySuperArguments
-        super(Worker, self).__init__(name=f"datadog-{name_index}", daemon=True, *args, **kwargs)
+        super(Worker, self).__init__(name=f"datadog-{name_index}", *args, **kwargs)
         self.api_key = api_key
         self.site = site
         self.queue = queue
@@ -35,13 +34,16 @@ class Worker(threading.Thread):
                             response = MetricsApi(api_client).submit_metrics(body=MetricPayload(series=items))
                             if response.errors:
                                 for i in response.errors:
-                                    logger.error(i)
+                                    logger.error(f"Datadog response: {i}")
                         except Exception as e:
-                            logger.error(f"{e.args}")
+                            logger.error(f"Got: {e.args}")
+                            queue_size = self.queue.qsize()
                             logger.debug(f"putting {len(items)} back -- queue length before {self.queue.qsize()}")
                             for item in items:
                                 self.queue.put(item)
-                            logger.debug(f"queue length after {self.queue.qsize()}")
+                            logger.debug(
+                                f"Put {len(items)} back into queue. Queue length before {queue_size}, after {self.queue.qsize()}"
+                            )
                             time.sleep(10)
                         items.clear()
                 send_now = False
